@@ -10,17 +10,18 @@ import sys
 from PyQt5.Qt import (Qt, QApplication, QStyle, QIcon,  QDoubleSpinBox, QStyleOptionViewItem,
         QSpinBox, QStyledItemDelegate, QComboBox, QTextDocument, QMenu, QKeySequence,
         QAbstractTextDocumentLayout, QFont, QFontInfo, QDate, QDateTimeEdit, QDateTime,
-        QStyleOptionComboBox, QStyleOptionSpinBox, QLocale, QSize)
+        QStyleOptionComboBox, QStyleOptionSpinBox, QLocale, QSize, QLineEdit)
 
+from calibre.ebooks.metadata import rating_to_stars
 from calibre.gui2 import UNDEFINED_QDATETIME, rating_font
 from calibre.constants import iswindows
 from calibre.gui2.widgets import EnLineEdit
-from calibre.gui2.widgets2 import populate_standard_spinbox_context_menu
+from calibre.gui2.widgets2 import populate_standard_spinbox_context_menu, RatingEditor
 from calibre.gui2.complete2 import EditWithComplete
 from calibre.utils.date import now, format_date, qt_to_dt, is_date_undefined
 from calibre.utils.config import tweaks
 from calibre.utils.icu import sort_key
-from calibre.gui2.dialogs.comments_dialog import CommentsDialog
+from calibre.gui2.dialogs.comments_dialog import CommentsDialog, PlainTextDialog
 from calibre.gui2.dialogs.template_dialog import TemplateDialog
 from calibre.gui2.dialogs.tag_editor import TagEditor
 from calibre.gui2.languages import LanguagesEdit
@@ -176,6 +177,7 @@ class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, *args, **kwargs):
         QStyledItemDelegate.__init__(self, *args, **kwargs)
+        self.is_half_star = kwargs.get('is_half_star', False)
         self.table_widget = args[0]
         self.rf = QFont(rating_font())
         self.em = Qt.ElideMiddle
@@ -184,33 +186,25 @@ class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
             delta = 2
         self.rf.setPointSize(QFontInfo(QApplication.font()).pointSize()+delta)
 
-    def createEditor(self, parent, option, index):
-        sb = QSpinBox(parent)
-        sb.setMinimum(0)
-        sb.setMaximum(5)
-        sb.setSuffix(' ' + _('stars'))
-        sb.setSpecialValueText(_('Not rated'))
-        return sb
-
     def get_required_width(self, editor, style, fm):
-        val = editor.maximum()
-        text = editor.textFromValue(val) + editor.suffix()
-        srect = style.itemTextRect(fm, editor.geometry(), Qt.AlignLeft, False,
-                                   text + u'M')
-        return srect.width()
+        return editor.sizeHint().width()
 
     def displayText(self, value, locale):
-        r = int(value)
-        if r < 0 or r > 5:
-            r = 0
-        return u'\u2605'*r
+        return rating_to_stars(value, self.is_half_star)
+
+    def createEditor(self, parent, option, index):
+        return RatingEditor(parent, is_half_star=self.is_half_star)
 
     def setEditorData(self, editor, index):
         if check_key_modifier(Qt.ControlModifier):
             val = 0
         else:
             val = index.data(Qt.EditRole)
-        editor.setValue(val)
+        editor.rating_value = val
+
+    def setModelData(self, editor, model, index):
+        val = editor.rating_value
+        model.setData(index, val, Qt.EditRole)
 
     def sizeHint(self, option, index):
         option.font = self.rf
@@ -224,6 +218,7 @@ class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 
 # }}}
 
+
 class DateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, parent, tweak_name='gui_timestamp_display_format',
@@ -391,6 +386,7 @@ class LanguagesDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def setModelData(self, editor, model, index):
         val = ','.join(editor.lang_codes)
+        editor.update_recently_used()
         model.setData(index, (val), Qt.EditRole)
 # }}}
 
@@ -456,11 +452,18 @@ class CcTextDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
     def createEditor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
-        editor = EditWithComplete(parent)
-        editor.set_separator(None)
-        complete_items = sorted(list(m.db.all_custom(label=m.db.field_metadata.key_to_label(col))),
-                                key=sort_key)
-        editor.update_items_cache(complete_items)
+        key = m.db.field_metadata.key_to_label(col)
+        if m.db.field_metadata[col]['datatype'] != 'comments':
+            editor = EditWithComplete(parent)
+            editor.set_separator(None)
+            complete_items = sorted(list(m.db.all_custom(label=key)), key=sort_key)
+            editor.update_items_cache(complete_items)
+        else:
+            editor = QLineEdit(parent)
+            text = index.data(Qt.DisplayRole)
+            if text:
+                editor.setText(text)
+                editor.selectAll()
         return editor
 
     def setEditorData(self, editor, index):
@@ -468,8 +471,36 @@ class CcTextDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
         editor.selectAll()
 
     def setModelData(self, editor, model, index):
-        val = editor.text()
-        model.setData(index, (val), Qt.EditRole)
+        val = editor.text() or ''
+        if not isinstance(editor, EditWithComplete):
+            val = val.strip()
+        model.setData(index, val, Qt.EditRole)
+# }}}
+
+class CcLongTextDelegate(QStyledItemDelegate):  # {{{
+
+    '''
+    Delegate for comments data.
+    '''
+
+    def __init__(self, parent):
+        QStyledItemDelegate.__init__(self, parent)
+        self.document = QTextDocument()
+
+    def createEditor(self, parent, option, index):
+        m = index.model()
+        col = m.column_map[index.column()]
+        if check_key_modifier(Qt.ControlModifier):
+            text = ''
+        else:
+            text = m.db.data[index.row()][m.custom_columns[col]['rec_index']]
+        d = PlainTextDialog(parent, text, column_name=m.custom_columns[col]['name'])
+        if d.exec_() == d.Accepted:
+            m.setData(index, d.text, Qt.EditRole)
+        return None
+
+    def setModelData(self, editor, model, index):
+        model.setData(index, (editor.textbox.html), Qt.EditRole)
 # }}}
 
 class CcNumberDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
